@@ -257,6 +257,10 @@ class NowThread(QThread):
                 traceback.print_exc()
                 self.communication.WidgetColorSignal.emit("fail")
 
+        else:
+            self.communication.WidgetColorSignal.emit("fail")
+            self.communication.signal2.emit("请登录后使用！")
+
     #当图片大小大于所限制的大小时，会调用此方法将图片进行大小的缩放
     def cut_jpg(self, pic_path):
         img = cv2.imdecode(np.fromfile(pic_path, dtype=np.uint8), cv2.IMREAD_COLOR)
